furo: A clean customizable Sphinx documentation theme
=====================================================

Description
-----------

A clean customizable Sphinx documentation theme.

License
-------

Upstream Contact
----------------

https://pypi.org/project/furo/

